@@ -8,10 +8,10 @@ use utf8;
 
 BEGIN {
 	$App::perlrdf::FileSpec::InputFile::AUTHORITY = 'cpan:TOBYINK';
-	$App::perlrdf::FileSpec::InputFile::VERSION   = '0.002';
+	$App::perlrdf::FileSpec::InputFile::VERSION   = '0.003';
 }
 
-use Any::Moose;
+use Moose;
 use IO::Scalar;
 use Path::Class;
 use namespace::clean;
