@@ -8,10 +8,10 @@ use utf8;
 
 BEGIN {
 	$App::perlrdf::FileSpec::InputRDF::AUTHORITY = 'cpan:TOBYINK';
-	$App::perlrdf::FileSpec::InputRDF::VERSION   = '0.002';
+	$App::perlrdf::FileSpec::InputRDF::VERSION   = '0.003';
 }
 
-use Any::Moose;
+use Moose;
 use RDF::Trine;
 use RDF::TriN3;
 use RDF::TrineX::Parser::Pretdsl;
