@@ -8,10 +8,10 @@ use utf8;
 
 BEGIN {
 	$App::perlrdf::FileSpec::OutputRDF::AUTHORITY = 'cpan:TOBYINK';
-	$App::perlrdf::FileSpec::OutputRDF::VERSION   = '0.002';
+	$App::perlrdf::FileSpec::OutputRDF::VERSION   = '0.003';
 }
 
-use Any::Moose;
+use Moose;
 use RDF::Trine;
 use RDF::TriN3;
 use RDF::TrineX::Functions -all => { -prefix => 'rdf_' };
